@@ -1,27 +1,8 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2008-10-09
- * @brief  internal private container for KDcraw
- *
- * @author Copyright (C) 2008-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2008-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kdcraw.h"
 #include "kdcraw_p.h"
@@ -42,7 +23,7 @@ int callbackForLibRaw(void* data, enum LibRaw_progress p, int iteration, int exp
 {
     if (data)
     {
-        KDcraw::Private* const d = static_cast<KDcraw::Private*>(data);
+        KDcrawPrivate* const d = static_cast<KDcrawPrivate*>(data);
 
         if (d)
         {
@@ -55,17 +36,15 @@ int callbackForLibRaw(void* data, enum LibRaw_progress p, int iteration, int exp
 
 // --------------------------------------------------------------------------------------------------
 
-KDcraw::Private::Private(KDcraw* const p)
+KDcrawPrivate::KDcrawPrivate(KDcraw* const p)
+    : m_parent(p)
 {
     m_progress = 0.0;
-    m_parent   = p;
 }
 
-KDcraw::Private::~Private()
-{
-}
+KDcrawPrivate::~KDcrawPrivate() = default;
 
-void KDcraw::Private::createPPMHeader(QByteArray& imgData, libraw_processed_image_t* const img)
+void KDcrawPrivate::createPPMHeader(QByteArray& imgData, libraw_processed_image_t* const img)
 {
     QString header = QString::fromUtf8("P%1\n%2 %3\n%4\n").arg(img->colors == 3 ? QLatin1String("6") : QLatin1String("5"))
                                                           .arg(img->width)
@@ -75,7 +54,7 @@ void KDcraw::Private::createPPMHeader(QByteArray& imgData, libraw_processed_imag
     imgData.append(QByteArray((const char*)img->data, (int)img->data_size));
 }
 
-int KDcraw::Private::progressCallback(enum LibRaw_progress p, int iteration, int expected)
+int KDcrawPrivate::progressCallback(enum LibRaw_progress p, int iteration, int expected)
 {
     qCDebug(LIBKDCRAW_LOG) << "LibRaw progress: " << libraw_strprogress(p) << " pass "
                            << iteration << " of " << expected;
@@ -86,7 +65,7 @@ int KDcraw::Private::progressCallback(enum LibRaw_progress p, int iteration, int
     // Clean processing termination by user...
     if (m_parent->checkToCancelWaitingData())
     {
-        qCDebug(LIBKDCRAW_LOG) << "LibRaw process terminaison invoked...";
+        qCDebug(LIBKDCRAW_LOG) << "LibRaw process termination invoked...";
         m_parent->m_cancel = true;
         m_progress         = 0.0;
         return 1;
@@ -96,20 +75,20 @@ int KDcraw::Private::progressCallback(enum LibRaw_progress p, int iteration, int
     return 0;
 }
 
-void KDcraw::Private::setProgress(double value)
+void KDcrawPrivate::setProgress(double value)
 {
     m_progress = value;
     m_parent->setWaitingDataProgress(m_progress);
 }
 
-double KDcraw::Private::progressValue() const
+double KDcrawPrivate::progressValue() const
 {
     return m_progress;
 }
 
-void KDcraw::Private::fillIndentifyInfo(LibRaw* const raw, DcrawInfoContainer& identify)
+void KDcrawPrivate::fillIndentifyInfo(LibRaw* const raw, DcrawInfoContainer& identify)
 {
-    identify.dateTime.setTime_t(raw->imgdata.other.timestamp);
+    identify.dateTime.setMSecsSinceEpoch(raw->imgdata.other.timestamp * 1000);
     identify.make             = QString::fromUtf8(raw->imgdata.idata.make);
     identify.model            = QString::fromUtf8(raw->imgdata.idata.model);
     identify.owner            = QString::fromUtf8(raw->imgdata.other.artist);
@@ -172,7 +151,7 @@ void KDcraw::Private::fillIndentifyInfo(LibRaw* const raw, DcrawInfoContainer& i
     }
 }
 
-bool KDcraw::Private::loadFromLibraw(const QString& filePath, QByteArray& imageData,
+bool KDcrawPrivate::loadFromLibraw(const QString& filePath, QByteArray& imageData,
                                      int& width, int& height, int& rgbmax)
 {
     m_parent->m_cancel = false;
@@ -322,7 +301,7 @@ bool KDcraw::Private::loadFromLibraw(const QString& filePath, QByteArray& imageD
                DSLR will have a high dominant of color that will lead to
                a completely wrong WB
             */
-            if (rawFileIdentify(identify, filePath))
+            if (KDcraw::rawFileIdentify(identify, filePath))
             {
                 RGB[0] = identify.daylightMult[0] / RGB[0];
                 RGB[1] = identify.daylightMult[1] / RGB[1];
@@ -598,7 +577,7 @@ bool KDcraw::Private::loadFromLibraw(const QString& filePath, QByteArray& imageD
     return true;
 }
 
-bool KDcraw::Private::loadEmbeddedPreview(QByteArray& imgData, LibRaw& raw)
+bool KDcrawPrivate::loadEmbeddedPreview(QByteArray& imgData, LibRaw& raw)
 {
     int ret = raw.unpack_thumb();
 
@@ -641,7 +620,7 @@ bool KDcraw::Private::loadEmbeddedPreview(QByteArray& imgData, LibRaw& raw)
     return true;
 }
 
-bool KDcraw::Private::loadHalfPreview(QImage& image, LibRaw& raw)
+bool KDcrawPrivate::loadHalfPreview(QImage& image, LibRaw& raw)
 {
     raw.imgdata.params.use_auto_wb   = 1;         // Use automatic white balance.
     raw.imgdata.params.use_camera_wb = 1;         // Use camera white balance, if possible.
@@ -675,7 +654,7 @@ bool KDcraw::Private::loadHalfPreview(QImage& image, LibRaw& raw)
         return false;
     }
 
-    Private::createPPMHeader(imgData, halfImg);
+    KDcrawPrivate::createPPMHeader(imgData, halfImg);
     // Clear memory allocation. Introduced with LibRaw 0.11.0
     raw.dcraw_clear_mem(halfImg);
     raw.recycle();
